# API reference

:::{card} C++ Documentation {fas}`external-link-alt`
:link: ../_static/doxygen/index.html

The C++ classes, cpu-kernels, and gpu-kernels are documented separately. Click here to go to the C++ API reference
:::

:::{eval-rst}
.. include:: toctree.txt
:::